==> hs-heist-0.5.2.1.tbz: lib/ghc-7.0.3/cabal/heist-0.5.2.1/register.sh <==
#!/bin/sh
echo 'name: heist
version: 0.5.2.1
id: heist-0.5.2.1-f1c02ac62261edaeabec8a593e10cf33

license: BSD3
copyright:
maintainer: snap@snapframework.com
stability:
homepage: http://snapframework.com/
package-url:
description: An xhtml templating system
category: Web
author: Doug Beardsley, Gregory Collins
exposed: True
exposed-modules: Text.Templating.Heist
                 Text.Templating.Heist.Splices Text.Templating.Heist.Splices.Apply
                 Text.Templating.Heist.Splices.Bind
                 Text.Templating.Heist.Splices.Cache
                 Text.Templating.Heist.Splices.Html
                 Text.Templating.Heist.Splices.Ignore
                 Text.Templating.Heist.Splices.Markdown
                 Text.Templating.Heist.Splices.Static
                 Text.Templating.Heist.TemplateDirectory
hidden-modules: Text.Templating.Heist.Internal
                Text.Templating.Heist.Types
import-dirs: /usr/local/lib/ghc-7.0.3/cabal/heist-0.5.2.1
library-dirs: /usr/local/lib/ghc-7.0.3/cabal/heist-0.5.2.1
              /usr/local/lib
hs-libraries: HSheist-0.5.2.1
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: MonadCatchIO-transformers-0.2.2.2-84aa40f69daa719524ae26f28e6cfb88
         attoparsec-0.9.1.1-7802949973df2994e2c3f765eadfeb1c
         attoparsec-text-0.8.5.1-db63b068068d8648cba94b4abc26808c
         base-4.3.1.0-93a63ba911a7eac625848432374f7fee
         blaze-builder-0.3.0.1-f04ac78deda4862ea589cfaee6d1e34d
         bytestring-0.9.1.10-8fbcae7fd1f192307195284611c786a2
         containers-0.4.0.0-18deac99a132f04751d862b77aab136e
         directory-1.1.0.0-ccdcf043bf8bcec9518fbfad880579a5
         directory-tree-0.10.0-dba4738e65e1de94eee4579c039549a5
         filepath-1.2.0.0-679ac50c41ba31bfc69abf444d9852e4
         mtl-2.0.1.0-9763a8821c812a910d327bad2c0d23b2
         process-1.0.1.5-4cab1bf0666275ac101dd48c7565b64c
         random-1.0.0.3-57524486875e0c4c260dd22788921013
         text-0.11.0.6-6ec4b304ae0e3c738fac5c5ec66848ad
         time-1.2.0.3-57ebba2cc05370f666b7eceba5e468a9
         transformers-0.2.2.0-a8a2dbba7d96131db605cf631ea0c8c4
         xmlhtml-0.1.5.2-d0afc8cae86315406505ac52e37b0dc6
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.3/cabal/heist-0.5.2.1/html/heist.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.3/cabal/heist-0.5.2.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-heist-0.7.0.1.tbz: lib/ghc-7.0.4/cabal/heist-0.7.0.1/register.sh <==
#!/bin/sh
echo 'name: heist
version: 0.7.0.1
id: heist-0.7.0.1-87621115d669ab402113591991daf87a

license: BSD3
copyright:
maintainer: snap@snapframework.com
stability:
homepage: http://snapframework.com/
package-url:
description: An (x)html templating system
category: Web, Snap
author: Doug Beardsley, Gregory Collins
exposed: True
exposed-modules: Text.Templating.Heist
                 Text.Templating.Heist.Splices Text.Templating.Heist.Splices.Apply
                 Text.Templating.Heist.Splices.Bind
                 Text.Templating.Heist.Splices.BindStrict
                 Text.Templating.Heist.Splices.Cache
                 Text.Templating.Heist.Splices.Html
                 Text.Templating.Heist.Splices.Ignore
                 Text.Templating.Heist.Splices.Markdown
                 Text.Templating.Heist.Splices.Static
                 Text.Templating.Heist.TemplateDirectory
hidden-modules: Text.Templating.Heist.Internal
                Text.Templating.Heist.Types
import-dirs: /usr/local/lib/ghc-7.0.4/cabal/heist-0.7.0.1
library-dirs: /usr/local/lib/ghc-7.0.4/cabal/heist-0.7.0.1
              /usr/local/lib
hs-libraries: HSheist-0.7.0.1
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: MonadCatchIO-transformers-0.2.2.3-e5999289aaa50b5bed30863ffa73c6fc
         attoparsec-0.10.1.0-22b85b2004ae392ff5cab099ffd0f453
         base-4.3.1.0-93a63ba911a7eac625848432374f7fee
         blaze-builder-0.3.1.0-19b8f4f8b5d83779c3b3e947a878bd26
         bytestring-0.9.1.10-8fbcae7fd1f192307195284611c786a2
         containers-0.4.0.0-18deac99a132f04751d862b77aab136e
         directory-1.1.0.0-ccdcf043bf8bcec9518fbfad880579a5
         directory-tree-0.10.0-dba4738e65e1de94eee4579c039549a5
         filepath-1.2.0.0-679ac50c41ba31bfc69abf444d9852e4
         mtl-2.0.1.0-9763a8821c812a910d327bad2c0d23b2
         process-1.0.1.5-4cab1bf0666275ac101dd48c7565b64c
         random-1.0.0.3-57524486875e0c4c260dd22788921013
         text-0.11.1.5-1ea395545cc7c8fb42ee757868e225d9
         time-1.2.0.3-57ebba2cc05370f666b7eceba5e468a9
         transformers-0.2.2.0-a8a2dbba7d96131db605cf631ea0c8c4
         xmlhtml-0.1.5.2-b8b9702fb57ff7f985adefe012d31645
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.4/cabal/heist-0.7.0.1/html/heist.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.4/cabal/heist-0.7.0.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
